==> Percept_15.2.3.2_RC.zip: PERCEPT-Body-Camera-English.md <==
## 15.2.3.2

- **Improved Live Streaming Reliability**: Streaming is now supported across a wider range of network configurations, ensuring more consistent connectivity in diverse environments.

## 15.2.2.10

- **Firmware Update Visibility**: Added support for near real-time firmware update status in PERCEPT Cloud.
- **Enhanced Firmware Update Process**: Firmware updates now proceed seamlessly when connected via LTE and the WiFi interface is set as an Access Point, provided the battery level meets the required threshold.
- **Improved Compatibility with ONVIF Recording Search**: The body camera now complies with the ONVIF Profile G specification, ensuring compatibility with the Recording Search service.
- **Improved Recording Integrity**: When the "Record Permanently" feature is enabled by an Administrator, recordings remain active and unaffected by Super user actions in the Live Viewer.

## 15.2.1.4

- **New "Disable Shutdown" Option**: A "Disable Shutdown" setting has been added to the configuration menu:
  - The setting is disabled by default.
  - When enabled, the camera cannot be shut down unless the setting is deactivated.
  - Overrides and disables the auto shutdown timeout.
- **New "Always Record" Option**: A "Always Record" setting has been introduced in the configuration menu:
  - The setting is disabled by default.
  - Recording starts automatically when the device boots and stops when docked in a PERCEPT docking station.
  - Recording resumes when undocked.
  - Privacy mode takes precedence over this setting and stops recording when activated.

## 15.2.0.26

- **Improved Device Onboarding**: Devices deleted and subsequently re-added to PERCEPT Cloud now come back online successfully within 5 minutes. This ensures a reliable and uninterrupted onboarding process for device management.

## 15.2.0.18

- **Accurate LTE Status Reporting**: The LTE status now reflects the current state of the LTE connection, including operator, signal strength, and SIM status, ensuring reliable visibility in PERCEPT Cloud.

## 15.2.0.16

- **Faster Video Archive Indexing**: The indexing process for video archives has been improved, allowing quicker access to recordings and reducing delays during retrieval.
- **Comprehensive File Indexing**: All files on the SD card are now indexed during the rebuild process, preventing recording interruptions caused by unindexed files.

## 15.2.0.6

- **Streamlined Configuration Templates**: Multi-template support has been disabled, allowing only one template per device. This ensures consistent and reliable behavior when managing configuration templates.
- **Reliable Integrations Tab**: The Integrations tab now loads content correctly in all supported configurations, ensuring seamless access to and management of integrations.
- **Automatic VPN Reconnection**: VPN connections now automatically reconnect if disconnected, maintaining continuous connectivity without manual intervention.
- **Persistent VPN Configuration**: VPN configurations remain operational after firmware updates, eliminating the need for reconfiguration and ensuring uninterrupted connectivity.

==> Percept_15.2.4.22_RC.zip: PERCEPT-Body-Camera-English.md <==
## 15.2.4.22

- **Improved Connectivity**: Connection between the PERCEPT Body Camera and PERCEPT Cloud remains stable and consistent even under limited bandwidth or after network transitions.
- **Enhanced Live Streaming Stability**: Real-time streaming from PERCEPT Cloud is now more reliable under limited connectivity or after a network change.

## 15.2.3.2

- **Improved Live Streaming Reliability**: Streaming is now supported across a wider range of network configurations, ensuring more consistent connectivity in diverse environments.

## 15.2.2.10

- **Firmware Update Visibility**: Added support for near real-time firmware update status in PERCEPT Cloud.
- **Enhanced Firmware Update Process**: Firmware updates now proceed seamlessly when connected via LTE and the WiFi interface is set as an Access Point, provided the battery level meets the required threshold.
- **Improved Compatibility with ONVIF Recording Search**: The body camera now complies with the ONVIF Profile G specification, ensuring compatibility with the Recording Search service.
- **Improved Recording Integrity**: When the "Record Permanently" feature is enabled by an Administrator, recordings remain active and unaffected by Super user actions in the Live Viewer.

## 15.2.1.4

- **New "Disable Shutdown" Option**: A "Disable Shutdown" setting has been added to the configuration menu:
  - The setting is disabled by default.
  - When enabled, the camera cannot be shut down unless the setting is deactivated.
  - Overrides and disables the auto shutdown timeout.
- **New "Always Record" Option**: A "Always Record" setting has been introduced in the configuration menu:
  - The setting is disabled by default.
  - Recording starts automatically when the device boots and stops when docked in a PERCEPT docking station.
  - Recording resumes when undocked.
  - Privacy mode takes precedence over this setting and stops recording when activated.

## 15.2.0.26

- **Improved Device Onboarding**: Devices deleted and subsequently re-added to PERCEPT Cloud now come back online successfully within 5 minutes. This ensures a reliable and uninterrupted onboarding process for device management.

## 15.2.0.18

- **Accurate LTE Status Reporting**: The LTE status now reflects the current state of the LTE connection, including operator, signal strength, and SIM status, ensuring reliable visibility in PERCEPT Cloud.

## 15.2.0.16

- **Faster Video Archive Indexing**: The indexing process for video archives has been improved, allowing quicker access to recordings and reducing delays during retrieval.
- **Comprehensive File Indexing**: All files on the SD card are now indexed during the rebuild process, preventing recording interruptions caused by unindexed files.

## 15.2.0.6

- **Streamlined Configuration Templates**: Multi-template support has been disabled, allowing only one template per device. This ensures consistent and reliable behavior when managing configuration templates.
- **Reliable Integrations Tab**: The Integrations tab now loads content correctly in all supported configurations, ensuring seamless access to and management of integrations.
- **Automatic VPN Reconnection**: VPN connections now automatically reconnect if disconnected, maintaining continuous connectivity without manual intervention.
- **Persistent VPN Configuration**: VPN configurations remain operational after firmware updates, eliminating the need for reconfiguration and ensuring uninterrupted connectivity.
